| Name:only_common
| Explanation:Please use it when you want to extract only the common
  part of two csv.

| License:MIT Using method:
| pip install only_common
| import only_common as oc
| oc.excommon(‘a.csv’, ‘b.csv’, ‘shift-jis’)
| >あいこかきこさ
